import datetime

today_str = datetime.datetime.now().strftime('%m/%d/%Y')

# check file or folder if exists 
# pth: the path of the file/folder
def isExist(pth):
	return Path(pth).exists()

# uppercase the first letter of the str
# eg: "I lOve yoU & and the family" =>"I Love You & And The Family"
def firstLetterToUpper(str):
	str = str.lower().strip()
	
	if " " in str:
		str = str.split(' ')
		new_str = ""
		
		for x in str:
			item =""
			n = 0
			for y in x:
				n += 1
				if n==1:
	 				if ord(x[0]) >=97 and ord(x[0]) <= 122:
	 					y = chr(ord(x[0])-32)
				item += y
		return new_str	
	else:
		return str.capitalize()



# -----------------colorama模块的一些常量---------------------------
# Fore: BLACK, RED, GREEN, YELLOW, BLUE, MAGENTA, CYAN, WHITE, RESET.
# Back: BLACK, RED, GREEN, YELLOW, BLUE, MAGENTA, CYAN, WHITE, RESET.
# Style: DIM, NORMAL, BRIGHT, RESET_ALL
#
  
from colorama import init, Fore, Back, Style

init(autoreset=True)

class Color(object):
  
  # 前景色:红色 背景色:默认
  def red(self, s):
    return Fore.RED + s + Fore.RESET
  
  # 前景色:绿色 背景色:默认
  def green(self, s):
    return Fore.GREEN + s + Fore.RESET
  
  # 前景色:黄色 背景色:默认
  def yellow(self, s):
    return Fore.YELLOW + s + Fore.RESET
  
  # 前景色:蓝色 背景色:默认
  def blue(self, s):
    return Fore.BLUE + s + Fore.RESET
  
  # 前景色:洋红色 背景色:默认
  def magenta(self, s):
    return Fore.MAGENTA + s + Fore.RESET
  
  # 前景色:青色 背景色:默认
  def cyan(self, s):
    return Fore.CYAN + s + Fore.RESET
  
  # 前景色:白色 背景色:默认
  def white(self, s):
    return Fore.WHITE + s + Fore.RESET
  
  # 前景色:黑色 背景色:默认
  def black(self, s):
    return Fore.BLACK
  
  # 前景色:白色 背景色:绿色
  def white_green(self, s):
    return Fore.WHITE + Back.GREEN + s + Fore.RESET + Back.RESET


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="slimz",
    version="0.0.4",
    author="scott",
    author_email="mbp98k@gmail.com",
    description="utils for python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/scott-x/pyutils",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
            'xlrd',
            'xlwt',
            'xlutils',
            'colorama'
    ]
)


import xlrd
import xlwt
import datetime
from xlutils.copy import copy

borders = xlwt.Borders()
borders.top = xlwt.Borders.THIN
borders.bottom = xlwt.Borders.THIN
borders.left = xlwt.Borders.THIN
borders.right = xlwt.Borders.THIN

alignment_center = xlwt.Alignment()
alignment_center.horz = xlwt.Alignment.HORZ_CENTER
alignment_center.vert = xlwt.Alignment.VERT_CENTER

alignment_left = xlwt.Alignment()
alignment_left.horz = xlwt.Alignment.HORZ_LEFT
alignment_left.vert = xlwt.Alignment.VERT_CENTER

alignment_right = xlwt.Alignment()
alignment_right.horz = xlwt.Alignment.HORZ_RIGHT
alignment_right.vert = xlwt.Alignment.VERT_CENTER

def font(name,height,isBold=False):
	font = xlwt.Font()
	font.name = name
	font.height = 20*height
	font.bold = isBold
	return font

def style(font("Arial",10),borders,alignment):
	style = xlwt.XFStyle()
	
	style.font = font
	style.borders = borders
	style.alignment = alignment

	return style

style1 = style(font1,borders,alignment_center)	

# parse the cell data, such as 1/1/2020 to 01/01/2020, if it's str, do nothing, just return str
def parseFloatTimeToString(row,col,sheet):
	res = ''
	if type(sheet.cell_value(row,col))==float:	
		res = xlrd.xldate.xldate_as_datetime(sheet.cell(row,col).value, 0).strftime( '%m/%d/%Y' )
	else:
		res = sheet.cell_value(row,col)	
	return res

# Book1 just for reading
class Book1(object):
	def __init__(self, filename):
		self.book = xlrd.open_workbook(filename)

	def sheet(self,index):	
		self.sheet = self.book.sheet_by_index(index)
		return self.sheet
	def cell_value(self,row,col):
		return self.sheet.cell_value(row,col)

# Book2 used for writing data with existing sheet template
class Book2(object):
	"""docstring for Book2"""
	def __init__(self, old_excle, new_excel):
		self.old_excle = old_excle
		self.new_excel = new_excel
		self.formatting_info = True

	def copy(self,old_sheet_index,new_sheet_index):
		old_workbook = xlrd.open_workbook(self.old_excle,self.formatting_info)
		# sheet
		target_sheet = old_workbook.sheet_by_index(old_sheet_index)

		new_excel = copy(old_workbook)
		new_sheet = new_excel.get_sheet(new_sheet_index)

		# 去掉页眉和页脚
		new_sheet.show_headers = False
		new_sheet.header_str = b''
		new_sheet.footer_str = b''
		self.book = new_excel
		self.sheet = new_sheet
		return self.sheet
		
	def write(self,row,col,value,style=style1):
		self.sheet.write(row, col, value,style)

	def save(self):
		self.book.save(self.new_excel)					

